@@ -86,7 +86,7 @@
 #define ATTICA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef ATTICA_NO_DEPRECATED
-#  define ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
+#  define ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54b00
 #endif
 #ifdef ATTICA_NO_DEPRECATED_WARNINGS
 #  define ATTICA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define ATTICA_DEPRECATED_WARNINGS_SINCE ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define ATTICA_DEPRECATED_WARNINGS_SINCE 0x54600
+#    define ATTICA_DEPRECATED_WARNINGS_SINCE 0x54b00
 #  endif
 #endif
 
@@ -130,5 +130,6 @@
 #define ATTICA_DEPRECATED_VERSION_0(minor, text)      ATTICA_DEPRECATED_VERSION_0_##minor(text)
 #define ATTICA_DEPRECATED_VERSION_5(minor, text)      ATTICA_DEPRECATED_VERSION_5_##minor(text)
 #define ATTICA_DEPRECATED_VERSION(major, minor, text) ATTICA_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define ATTICA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) ATTICA_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* ATTICA_EXPORT_H */
